For developers
==============

.. toctree::
   :maxdepth: 1

   Advice for FluidDyn developers <http://fluiddyn.readthedocs.io/en/latest/advice_developers.html>
   for_dev/todo
   for_dev/debug
   for_dev/pypy
   for_dev/typing
